---
name: Bug report
about: Report a Bug in Piqueserver
title: ''
labels: bug, triage
assignees: ''

---

**Describe the bug**
A description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Join Game '...'
2. Run command  '....'
3. Do '....'
4. See error

**Expected behavior**
A description of what you expected to happen.

**Stack Trace or logs**
<!-- If an error is displayed on the console, please upload it to gist.github.com, pastebin or a similar service and post the link here -->
<!-- If you face issues with script or map loading, please attach the startup logs -->

**Server (please complete the following information):**
 - OS/Version: [e.g. Ubuntu 18.04]
 - Piqueserver Version: run `piqueserver --version` to see the version.
 - Installation Method: pip, git, etc.

**Client (if relevant)**
 - Name: [e.g. OpenSpades, BetterSpades]
 - Version: [e.g. 1.3.0]

**Additional context**
Add any other context about the problem here.
